@@ -1,10 +1,9 @@
 from metapub import PubMedFetcher
-from scidownl.scihub import *
 import os
-from util import Diff, checkDir
+from .util import checkDir
 import json
-import ncbi
-from download import pdfDownload
+from .ncbi import getCitedby, getReferences
+from .download import pdfDownload
 
 class Article:
     def __init__(self, pmid, query):
@@ -19,13 +18,14 @@ class Article:
 
     def format_json(self):
         data = {}
-        citedby = ncbi.getCitedby(self.pmid)
-        refer = ncbi.getReferences(self.pmid)
+        citedby = getCitedby(self.pmid)
+        refer = getReferences(self.pmid)
         data.update({'pmid':self.pmid,
                     'authors':self.article.authors,
                     'year':self.article.year,
                     'title':self.article.title, 
-                    'abstract':self.article.abstract})
+                    'abstract':self.article.abstract,
+                    'doi':self.doi})
         if refer: data.update(refer)
         if citedby: data.update(citedby)
         if self.query:
@@ -37,11 +37,4 @@ class Article:
 
     def download(self):
         if not os.path.isfile("./pdf/{}.pdf".format(self.pmid)):
-            pdfDownload(self.pmid, self.doi)
-            # pdf_dir = checkDir('./pdf')
-            # old_dir = os.listdir(pdf_dir)
-            # sci = SciHub(doi, pdf_dir).download(choose_scihub_url_index=3)
-            # new_dir = os.listdir(pdf_dir)
-            # pdfname = Diff(old_dir, new_dir)[0]
-            # source = os.path.join(pdf_dir, pdfname)
-            # os.rename(source, os.path.join(pdf_dir, '{}.pdf'.format(self.pmid)))
\ No newline at end of file
+            pdfDownload(self.pmid, self.doi)
\ No newline at end of file
