@@ -1,6 +1,7 @@
 import urllib.request
 import requests
 from bs4 import BeautifulSoup
+from .util import checkDir
 
 def pdfDownload(pmid, doi):
     url = 'https://sci-hub.se/{}'.format(doi)
@@ -8,7 +9,9 @@ def pdfDownload(pmid, doi):
     html = r.content
     soup = BeautifulSoup(html, 'html.parser')
     pdf_url = soup.embed['src']
-    print(pdf_url)
-    response = urllib.request.urlopen(pdf_url)    
-    with open('./pdf/{}.pdf'.format(pmid), 'wb') as f:
-        f.write(response.read())
\ No newline at end of file
+    # print(pdf_url)
+    response = urllib.request.urlopen(pdf_url)   
+    save_path = checkDir('./pdf')
+    with open('{}/{}.pdf'.format(save_path, pmid), 'wb') as f:
+        f.write(response.read())
+    print('{} Downloaded - {}'.format(pmid, doi))
\ No newline at end of file
